//+------------------------------------------------------------------+
//|                                                       Sample.mq5 |
//|                                                  Copyright keiji |
//|                                   http://www.dr-ea.com/meta-blog/|
//+------------------------------------------------------------------+
#property copyright "keiji"
#property link      "http://www.dr-ea.com/meta-blog/"


#include <MQL4toMQL5/MQL4toMQL5_TechnicalIndicators.mqh>
//#include <MQL4toMQL5_TechnicalIndicators.mqh>                       //  Include/MQL4toMQL5_TechnicalIndicators.mqh

/*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::
MQL4                          MQL5

Applied price constants.
PRICE_CLOSE 0                 PRICE_CLOSE 1
PRICE_OPEN 1                  PRICE_OPEN 2
PRICE_HIGH 2 ...              PRICE_HIGH 3 ...  

iBands
input Applied price           input MA Method   ...Applied price According to the reference???



::::::::::::::::::::::::::::::::::::::::::::::::::::::::::*/

//--- input parameters
input string            _____MA_Parameters_____ = "_____Moving Average_____";
input ENUM_TIMEFRAMES   MA_TimeFrame  = PERIOD_H1;
input int               MA_Period      = 21;
input int               MA_Shift       = 0;
input ENUM_MA_METHOD    MA_Method      = MODE_SMA;
input ENUM_APPLIED_PRICE MA_Applied = PRICE_CLOSE;
input int               MA_BarsShift   = 1;

input string            _____Bands_Parameters_____ = "_____Bollinger bands_____";
input ENUM_TIMEFRAMES   Bands_TimeFrame = PERIOD_M30;
input int               Bands_Period   = 21;
input double            Bands_Deviation = 2.5;
input int               Bands_Shift    = 0;
input ENUM_MA_METHOD    Bands_Method = MODE_SMA;
input int               Bands_BarsShift   = 0;

input string            _____RSI_Parameters_____ = "_____Relative Strength Index_____";
input ENUM_TIMEFRAMES   RSI_TimeFrame  = PERIOD_M5;
input int               RSI_Period     = 14;
input ENUM_APPLIED_PRICE RSI_Applied = PRICE_CLOSE;
input int               RSI_BarsShift   = 0;


//+------------------------------------------------------------------+
//| Expert initialization function                                   |
//+------------------------------------------------------------------+
int OnInit()
  {
//---
   OnTick();
//---
   return(0);
  }
//+------------------------------------------------------------------+
//| Expert deinitialization function                                 |
//+------------------------------------------------------------------+
void OnDeinit(const int reason)
  {
//---
   Comment("");
   
  }
//+------------------------------------------------------------------+
//| Expert tick function                                             |
//+------------------------------------------------------------------+
void OnTick()
  {
//---
   //:::::::::::::::::::::::::::::::::::::::::::::::
   double Ask=SymbolInfoDouble(Symbol(),SYMBOL_ASK);
   double Bid=SymbolInfoDouble(Symbol(),SYMBOL_BID);
   //
   int Bars=Bars(Symbol(),PERIOD_CURRENT);
   double Point=Point();
   //:::::::::::::::::::::::::::::::::::::::::::::::

   double ma=iMA4( NULL, MA_TimeFrame, MA_Period, MA_Shift, MA_Method, MA_Applied, MA_BarsShift);
   double bandsup=iBands4( NULL, Bands_TimeFrame, Bands_Period, Bands_Deviation, Bands_Shift, Bands_Method, MODE_UPPER, Bands_BarsShift);
   double bandslow=iBands4( NULL, Bands_TimeFrame, Bands_Period, Bands_Deviation, Bands_Shift, Bands_Method, MODE_LOWER, Bands_BarsShift);
   double rsi=iRSI4( NULL, RSI_TimeFrame, RSI_Period, RSI_Applied, RSI_BarsShift);
   if(ma==EMPTY_VALUE || bandsup==EMPTY_VALUE || bandslow==EMPTY_VALUE || rsi==EMPTY_VALUE)
   {
      Comment("...");
      return;
   }
   
   string cmt="\n";
   cmt=cmt+FuncTMFstr(MA_TimeFrame)+" MA"+IntegerToString(MA_Period)+"["+IntegerToString(MA_BarsShift)+"]  "+DoubleToString(ma,Digits()+1)+"\n";
   cmt=cmt+FuncTMFstr(Bands_TimeFrame)+" BandsUP"+IntegerToString(Bands_Period)+"["+IntegerToString(Bands_BarsShift)+"]  "+DoubleToString(bandsup,Digits()+1)+"\n";
   cmt=cmt+FuncTMFstr(Bands_TimeFrame)+" BandsLOW"+IntegerToString(Bands_Period)+"["+IntegerToString(Bands_BarsShift)+"]  "+DoubleToString(bandslow,Digits()+1)+"\n";
   cmt=cmt+FuncTMFstr(RSI_TimeFrame)+" RSI"+IntegerToString(RSI_Period)+"["+IntegerToString(RSI_BarsShift)+"]  "+DoubleToString(rsi,Digits()+1)+"\n";
   Comment(cmt);

   
}

//+------------------------------------------------------------------+



string FuncTMFstr(int tmf)
{
   switch(tmf)
   {
      case 0: return("CURRENT");
      case 1: return("M1");
      case 5: return("M5");
      case 15: return("M15");
      case 30: return("M30");
      case 60: return("H1");
      case 240: return("H4");
      case 1440: return("D1");
      case 10080: return("W1");
      case 43200: return("MN1");
      
      case 2: return("M2");
      case 3: return("M3");
      case 4: return("M4");      
      case 6: return("M6");
      case 10: return("M10");
      case 12: return("M12");
      case 16385: return("H1");
      case 16386: return("H2");
      case 16387: return("H3");
      case 16388: return("H4");
      case 16390: return("H6");
      case 16392: return("H8");
      case 16396: return("H12");
      case 16408: return("D1");
      case 32769: return("W1");
      case 49153: return("MN1");      

      default: return("CURRENT");
   }
}